@@ -2,8 +2,7 @@
 # -*- coding: utf-8 -*-
 
 ###################
-#    This package implements a web server to run scripts or executables
-#    from the command line and display the result in a web interface.
+#    This tools run scripts and display the result in a Web Interface.
 #    Copyright (C) 2021  Maurice Lambert
 
 #    This program is free software: you can redistribute it and/or modify
@@ -20,9 +19,7 @@
 #    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 ###################
 
-"""This package implements a web server to run scripts or 
-executables from the command line and display the result 
-in a web interface.
+"""This tools run scripts and display the result in a Web Interface.
 
 This file implement commons functions and class for WebScripts package."""
 
@@ -40,13 +37,12 @@ from time import time
 import secrets
 import json
 
-__version__ = "0.0.9"
+__version__ = "0.0.10"
 __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
 __maintainer_email__ = "mauricelambert434@gmail.com"
-__description__ = """This package implements a web server to run scripts or 
-executables from the command line and display the result in a web interface.
+__description__ = """This tools run scripts and display the result in a Web Interface.
 
 This file implement commons functions and class for WebScripts package."""
 __license__ = "GPL-3.0 License"
@@ -206,6 +202,7 @@ class ScriptConfig(DefaultNamespace):
     __defaults__ = {
         "documentation_content_type": "text/html",
         "command_generate_documentation": None,
+        "stderr_content_type": "text/plain",
         "content_type": "text/plain",
         "documentation_file": None,
         "minimum_access": None,
@@ -222,6 +219,7 @@ class ScriptConfig(DefaultNamespace):
     __optional__ = [
         "command_generate_documentation",
         "documentation_content_type",
+        "stderr_content_type",
         "documentation_file",
         "minimum_access",
         "access_groups",
@@ -355,9 +353,8 @@ class ScriptConfig(DefaultNamespace):
             )
             script_section["name"] = name
 
-            script_section["path"] = script_path = get_real_path(
-                script_section.get("path")
-            )
+            path_ = script_section.get("path")
+            script_section["path"] = script_path = get_real_path(path_)
             if script_path is None:
                 script_section["path"] = cls.get_script_path(
                     server_configuration, script_section
@@ -377,6 +374,11 @@ class ScriptConfig(DefaultNamespace):
             scripts_config[name] = cls.default_build(**script_section)
             scripts_config[name].build_args(configuration)
 
+            if path_ is None:
+                scripts_config[name].path_is_defined = False
+            else:
+                scripts_config[name].path_is_defined = True
+
         return scripts_config
 
     @staticmethod
@@ -638,20 +640,20 @@ class CallableFile(Callable):
         if self.type == "js":
             return (
                 "200 OK",
-                {"Content-Type": "text/javascript"},
+                {"Content-Type": "text/javascript; charset=utf-8"},
                 get_file_content(self.path, "rb"),
             )
         elif self.type == "static":
             if self.is_html():
                 return (
                     "200 OK",
-                    {"Content-Type": "text/html"},
+                    {"Content-Type": "text/html; charset=utf-8"},
                     get_file_content(self.path, "rb"),
                 )
             elif self.extension == ".css":
                 return (
                     "200 OK",
-                    {"Content-Type": "text/css"},
+                    {"Content-Type": "text/css; charset=utf-8"},
                     get_file_content(self.path, "rb"),
                 )
             elif self.extension == ".ico":
@@ -681,25 +683,25 @@ class CallableFile(Callable):
             elif self.extension == ".json":
                 return (
                     "200 OK",
-                    {"Content-Type": "application/json"},
+                    {"Content-Type": "application/json; charset=utf-8"},
                     get_file_content(self.path, "rb"),
                 )
             elif self.extension == ".txt":
                 return (
                     "200 OK",
-                    {"Content-Type": "text/plain"},
+                    {"Content-Type": "text/plain; charset=utf-8"},
                     get_file_content(self.path, "rb"),
                 )
             elif self.extension == ".pdf":
                 return (
                     "200 OK",
-                    {"Content-Type": "application/pdf"},
+                    {"Content-Type": "application/pdf; charset=utf-8"},
                     get_file_content(self.path, "rb"),
                 )
             elif self.extension == ".csv":
                 return (
                     "200 OK",
-                    {"Content-Type": "text/csv"},
+                    {"Content-Type": "text/csv; charset=utf-8"},
                     get_file_content(self.path, "rb"),
                 )
             elif self.is_tiff():
@@ -711,7 +713,7 @@ class CallableFile(Callable):
             elif self.is_xml():
                 return (
                     "200 OK",
-                    {"Content-Type": "application/xml"},
+                    {"Content-Type": "application/xml; charset=utf-8"},
                     get_file_content(self.path, "rb"),
                 )
             elif self.extension == ".svg":
@@ -731,7 +733,7 @@ class CallableFile(Callable):
             return (
                 "200 OK",
                 {
-                    "Content-Type": "text/html",
+                    "Content-Type": "text/html; charset=utf-8",
                     "Content-Security-Policy": f"default-src 'self'; form-action 'none'; frame-ancestors 'none'; script-src 'self' 'nonce-{nonce}'",
                 },
                 CallableFile.template_script
